Record

Struct Record 

pub struct Record<'ast> { /* private fields */ }
A Nickel record being constructed

Implementations

Source

impl<'ast> Record<'ast>

pub fn new() -> Self

Make a new, empty record builder

pub fn field(self, name: impl AsRef<str>) -> Field<'ast, Record<'ast>>

Start constructing a field with the given name

pub fn fields<I, It>(self, alloc: &'ast AstAlloc, fields: It) -> Self
where I: Into<Field<'ast, Complete<'ast>>>, It: IntoIterator<Item = I>,

Attach possibly multiple fields to this record

pub fn include(self, ident: LocIdent) -> Self

Adds an include expression (define a field by taking it from the outer environment).

pub fn include_with_metadata( self, ident: LocIdent, metadata: FieldMetadata<'ast>, ) -> Self

Adds an include expression with associated metadata.

pub fn path<It, I>(self, path: It) -> Field<'ast, Record<'ast>>
where I: AsRef<str>, It: IntoIterator<Item = I>,

Start constructing a field at the given path

pub fn open(self) -> Self

Mark this record as “open” when used as a contract

pub fn set_open(self, open: bool) -> Self

Mark this record as “open” when used as a contract, depending on the value of open

pub fn build(self, alloc: &'ast AstAlloc) -> Ast<'ast>

Finalize the record and turn it into a super::Ast

pub fn from_iterator<I, It>(alloc: &'ast AstAlloc, fields: It) -> Self
where I: Into<Field<'ast, Complete<'ast>>>, It: IntoIterator<Item = I>,

Creates a record from an iterator of finalized fields.

We can’t implement FromIterator for Record because we need to provide an additional allocator.