pub enum MergePriority {
Bottom,
Neutral,
Numeral(Number),
Top,
}Variants
Bottom
The priority of default values that are overridden by everything else.
Neutral
The priority by default, when no priority annotation (default, force, priority) is
provided.
Act as the value MergePriority::Numeral(0) with respect to ordering and equality
testing. The only way to discriminate this variant is to pattern match on it.
Numeral(Number)
A numeral priority.
Top
The priority of values that override everything else and can’t be overridden.