StringChunk

Enum StringChunk 

pub enum StringChunk<E> {
    Literal(String),
    Expr(E, usize),
}
A chunk of a string with interpolated expressions inside. Can be either a string literal or an interpolated expression.

Variants



Literal(String)

A string literal.



Expr(E, usize)

An interpolated expression.

Implementations

Source

impl<E> StringChunk<E>

pub fn try_chunks_as_static_str<'a, I>(chunks: I) -> Option<String>
where I: IntoIterator<Item = &'a StringChunk<E>>, E: 'a,