pub struct PatBinding<'ast> {
pub path: Vec<LocIdent>,
pub id: LocIdent,
pub metadata: FieldMetadata<'ast>,
}Expand description
A variable bound in a pattern, together with the path to the field it matches and the associated extra annotations.
Fields
path: Vec<LocIdent>id: LocIdentmetadata: FieldMetadata<'ast>Auto Trait Implementations
impl<'ast> Freeze for PatBinding<'ast>
impl<'ast> RefUnwindSafe for PatBinding<'ast>
impl<'ast> Send for PatBinding<'ast>
impl<'ast> Sync for PatBinding<'ast>
impl<'ast> Unpin for PatBinding<'ast>
impl<'ast> UnsafeUnpin for PatBinding<'ast>
impl<'ast> UnwindSafe for PatBinding<'ast>