pub struct ArrayPattern<'ast> {
pub patterns: &'ast [Pattern<'ast>],
pub tail: TailPattern,
pub pos: TermPos,
}Expand description
An array pattern.
Fields
patterns: &'ast [Pattern<'ast>]The patterns of the elements of the array.
tail: TailPatternThe tail of the pattern, indicating if the pattern is open, i.e. if it ended with an ellipsis, capturing the rest or not.
pos: TermPosImplementations