pub struct FieldPattern<'ast> {
pub matched_id: LocIdent,
pub annotation: Annotation<'ast>,
pub default: Option<Ast<'ast>>,
pub pattern: Pattern<'ast>,
pub pos: TermPos,
}Expand description
A field pattern inside a record pattern. Every field can be annotated with a type, contracts or with a default value.
Fields
matched_id: LocIdentThe name of the matched field. For example, in {..., foo = {bar, baz}, ...}, the matched
identifier is foo.
annotation: Annotation<'ast>Type and contract annotations of this field.
default: Option<Ast<'ast>>Potential default value, set with the ? value syntax.
pattern: Pattern<'ast>The pattern on the right-hand side of the =. A pattern like {foo, bar}, without the =
sign, is parsed as {foo=foo, bar=bar}. In this case, pattern.data will be
PatternData::Any.
pos: TermPosTrait Implementations
Sourceimpl<'ast> Clone for FieldPattern<'ast>
impl<'ast> Clone for FieldPattern<'ast>
Sourcefn clone(&self) -> FieldPattern<'ast>
fn clone(&self) -> FieldPattern<'ast>
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CloneTo for FieldPattern<'_>
impl CloneTo for FieldPattern<'_>
Sourcetype Data<'ast> = FieldPattern<'ast>
type Data<'ast> = FieldPattern<'ast>
This is always
Self, be we need associated types to make Rust understand that Self is
always parametric over the 'ast lifetime. We’re using GATs to emulate higher-kinded
types.Sourceimpl<'ast> Debug for FieldPattern<'ast>
impl<'ast> Debug for FieldPattern<'ast>
Sourceimpl<'ast> PartialEq for FieldPattern<'ast>
impl<'ast> PartialEq for FieldPattern<'ast>
Sourceimpl<'ast> TraverseAlloc<'ast, Ast<'ast>> for FieldPattern<'ast>
impl<'ast> TraverseAlloc<'ast, Ast<'ast>> for FieldPattern<'ast>
Sourcefn traverse<F, E>(
self,
alloc: &'ast AstAlloc,
f: &mut F,
order: TraverseOrder,
) -> Result<Self, E>
fn traverse<F, E>( self, alloc: &'ast AstAlloc, f: &mut F, order: TraverseOrder, ) -> Result<Self, E>
Same as Traverse::traverse, but takes an additional AST allocator.
Sourcefn traverse_ref<S, U>(
&'ast self,
f: &mut dyn FnMut(&'ast Ast<'ast>, &S) -> TraverseControl<S, U>,
scope: &S,
) -> Option<U>
fn traverse_ref<S, U>( &'ast self, f: &mut dyn FnMut(&'ast Ast<'ast>, &S) -> TraverseControl<S, U>, scope: &S, ) -> Option<U>
Same as Traverse::traverse_ref, but takes an additional AST allocator. Read more
fn find_map<S>(&'ast self, pred: impl FnMut(&'ast T) -> Option<S>) -> Option<S>where
T: Clone + 'ast,
impl Allocable for FieldPattern<'_>
impl<'ast> Eq for FieldPattern<'ast>
impl<'ast> StructuralPartialEq for FieldPattern<'ast>