Pattern

Struct Pattern 

pub struct Pattern<'ast> {
    pub data: PatternData<'ast>,
    pub alias: Option<LocIdent>,
    pub pos: TermPos,
}
A generic pattern, that can appear in a match expression (not yet implemented) or in a destructuring let-binding.

Fields

data: PatternData<'ast>

The content of this pattern

alias: Option<LocIdent>

A potential alias for this pattern, capturing the whole matched value. In the source language, an alias is introduced by x @ <pattern>, where x is an arbitrary identifier.

pos: TermPos

The position of the pattern in the source.

Implementations

Source

impl Pattern<'_>

pub fn any(id: LocIdent) -> Self

Creates an Any pattern with the corresponding capture name.

pub fn try_as_any(&self) -> Option<LocIdent>

Returns Some(id) if this pattern is an PatternData::Any pattern, None otherwise.