pub struct RecordPattern<'ast> {
pub patterns: &'ast [FieldPattern<'ast>],
pub tail: TailPattern,
pub pos: TermPos,
}Expand description
A record pattern.
Fields
patterns: &'ast [FieldPattern<'ast>]The patterns for each field in the record.
tail: TailPatternThe tail of the pattern, indicating if the pattern is open, i.e. if it ended with an ellipsis, capturing the rest or not.
pos: TermPosImplementations
Sourceimpl RecordPattern<'_>
impl RecordPattern<'_>
Sourcepub fn check_dup(&self) -> Result<(), ParseError>
pub fn check_dup(&self) -> Result<(), ParseError>
Check the matches for duplication, and raise an error if any occurs.
Note that for backwards-compatibility reasons this function only checks top-level matches. In Nickel 1.0, this code panicked:
let f = fun { x, x, .. } => x in f { x = 1 }However this “works”, even though the binding to y is duplicated.
let f =
fun { x = { y }, z = { y }, .. } => y
in f { x = { y = 1 }, z = { y = 2 } }
# evaluates to 1This function aims to raise errors in the first case, but maintain the behaviour in the second case.