pub enum FieldPathElem<'ast> {
Ident(LocIdent),
Expr(Ast<'ast>),
}Expand description
Element of a record field path in a record field definition. For example, in { a."%{"hello-" ++ "world"}".c = true }, the path a."%{b}".c is composed of three elements: an identifier
a, an expression "hello" ++ "world", and another identifier c.
Variants
Ident(LocIdent)
A statically known identifier.
Expr(Ast<'ast>)
A dynamic field name written as a quoted expression, e.g. "%{protocol}" = .. . Normally,
the expression must be a crate::ast::Node::StringChunks, so we could store the
chunks directly which would be more precise. However, it’s useful to keep a general
crate::ast::Ast to store errors when part of the field path failed to parse
correctly.
Implementations
Sourceimpl<'ast> FieldPathElem<'ast>
impl<'ast> FieldPathElem<'ast>
Sourcepub fn expr(expr: Ast<'ast>) -> Self
pub fn expr(expr: Ast<'ast>) -> Self
Build a field path element from an expression. Automatically convert an expression that is actually a static identifier to Self::Ident.
Sourcepub fn single_ident_path(
alloc: &'ast AstAlloc,
ident: LocIdent,
) -> &'ast [FieldPathElem<'ast>]
pub fn single_ident_path( alloc: &'ast AstAlloc, ident: LocIdent, ) -> &'ast [FieldPathElem<'ast>]
Crate a path composed of a single static identifier.
Sourcepub fn single_expr_path(
alloc: &'ast AstAlloc,
expr: Ast<'ast>,
) -> &'ast [FieldPathElem<'ast>]
pub fn single_expr_path( alloc: &'ast AstAlloc, expr: Ast<'ast>, ) -> &'ast [FieldPathElem<'ast>]
Create a path composed of a single dynamic expression.
Sourcepub fn try_as_ident(&self) -> Option<LocIdent>
pub fn try_as_ident(&self) -> Option<LocIdent>
Try to interpret this element as a static identifier. Returns None if the element
is an expression with interpolation inside. Dual of Self::try_as_dyn_expr.
We assume that the parser has already normalized expressions that are actually static identifiers. So this method is a simple selector over Self::Ident.
Sourcepub fn try_as_dyn_expr(&self) -> Option<&Ast<'ast>>
pub fn try_as_dyn_expr(&self) -> Option<&Ast<'ast>>
Tries to interpret this element as a dynamic identifier. Returns None if the element is a
static identifier (that is, if Self::try_as_ident returns Some(_)).