FieldDef

Struct FieldDef 

pub struct FieldDef<'ast> {
    pub path: &'ast [FieldPathElem<'ast>],
    pub metadata: FieldMetadata<'ast>,
    pub value: Option<Ast<'ast>>,
    pub pos: TermPos,
}
A field definition. A field is defined by a dot-separated path of identifier or interpolated strings, a potential value, and associated metadata.

Fields

path: &'ast [FieldPathElem<'ast>]

A sequence of field path elements, composing the left hand side (with respect to the =) of the field definition.

Invariants

Important: The path must be non-empty, or some of FieldDef methods will panic.

metadata: FieldMetadata<'ast>

The metadata and the optional value bundled as a field.

value: Option<Ast<'ast>>pos: TermPos

The position of the whole field definition.

Implementations

Source

impl FieldDef<'_>

pub fn path_as_ident(&self) -> Option<LocIdent>

Returns the identifier corresponding to this definition if the path is composed of exactly one element which is a static identifier. Returns None otherwise.

pub fn name_as_ident(&self) -> Option<LocIdent>

Returns the declared field name, that is the last element of the path, as a static identifier. Returns None if the last element is an expression.

pub fn root_as_ident(&self) -> Option<LocIdent>

Returns the root identifier of the field path, that is the first element of the path, as a static identifier. Returns None if the first element is an expression.