Environment

Struct Environment 

pub struct Environment<K: Hash + Eq, V: PartialEq> { /* private fields */ }
An environment as a linked-list of hashmaps.

Each node of the linked-list corresponds to what is called “a layer”, where only the current layer can be modified, the previous ones are only accessible for lookup.

For the generic parameters, K is the type for the environment keys, and V are their value.

The linked list is composed of the current layer and the previous layers. The current layer is stored as an Rc<Hashmap>.

Insertions are made by “split-on-write”: if the current layer has no other references, it is mutated. If it has other references, the current layer is pushed down as the new “previous” layer, and a new layer is started.

Implementations

Source

impl<K: Hash + Eq, V: PartialEq> Environment<K, V>

pub fn new() -> Self

Creates a new empty Environment.

pub fn insert(&mut self, key: K, value: V)

Inserts a key-value pair into the Environment.

pub fn get(&self, key: &K) -> Option<&V>

Tries to find the value of a key in the Environment.

pub fn iter_layers(&self) -> EnvLayerIter<'_, K, V>

Creates an iterator that visits all layers from the most recent one to the oldest. The element iterator type is Rc<HashMap<K, V>>.

pub fn iter_elems(&self) -> impl Iterator<Item = (&K, &V)>

Creates an iterator that visits all elements from the Environment, from the oldest layer to the most recent one. It uses this order, so calling collect on this iterator to create a hashmap would have the same values as the Environment. The element iterator type is (&'env K, &'env V), with 'env being the lifetime of the Environment.

pub fn ptr_eq(this: &Self, that: &Self) -> bool

Checks quickly if two environments are obviously equal (when their components are physically equal as pointers or obviously equal such as being both empty).

pub fn is_empty(&self) -> bool

Returns true if this environment is empty, that is if the current layer is empty and there’s no previous layer.