pub struct FileId(/* private fields */);Expand description
A file identifier, which can be used to access a file in a Files.
Note that there is no protection against using a FileId for the wrong
instance of Files.