Files

Struct Files 

pub struct Files { /* private fields */ }
A cheaply-clonable, persistent, codespan-compatible collection of files.

Files knows about the nickel standard library, and automatically loads it on creation (but it doesn’t do parsing, or anything particularly expensive).

Cloning a Files is cheap, and the underlying file data will be shared between clones until one of them wants to modify a file. In that case, only the modified file(s) will be duplicated.

Implementations

Source

impl Files

pub fn empty() -> Self

pub fn new<Name, Contents, I>(stdlib_modules: I) -> Self
where Name: Into<OsString>, Contents: Into<Arc<str>>, I: IntoIterator<Item = (Name, Contents)>,

Creates a new Files, initialized with the nickel standard library.

pub fn is_stdlib(&self, id: FileId) -> bool

Does this file id point to a standard library file?

pub fn stdlib_modules(&self) -> impl Iterator<Item = FileId> + use<>

Returns the list of file ids of stdlib modules, in the order they were passed to Files::new.

pub fn add( &mut self, name: impl Into<OsString>, source: impl Into<Arc<str>>, ) -> FileId

Adds a file to this collection, creating and returning a new file id.

The name does not need to be unique, and this method does not affect any other files with the same name.

pub fn update(&mut self, file_id: FileId, source: impl Into<Arc<str>>)

Updates a source file in place.

Panics if file_id is invalid.

pub fn source_span(&self, file_id: FileId) -> RawSpan

Returns a span containing all of a source.

Panics if file_id is invalid.

pub fn name(&self, id: FileId) -> &OsStr

Returns the source’s name.

Panics if file_id is invalid.

pub fn source(&self, id: FileId) -> &str

Returns a source’s contents.

pub fn clone_source(&self, id: FileId) -> Arc<str>

Returns a cloned reference to the source’s contents

pub fn source_slice(&self, span: RawSpan) -> &str

Returns a slice of the source’s contents.

pub fn location( &self, id: FileId, byte_index: impl Into<ByteIndex>, ) -> Result<Location, Error>

Returns the codespan::Location (basically: line + col) corresponding to a byte index.

Returns an error if the byte index is out of bounds or fails to point to a UTF-8 char boundary.

pub fn filenames(&self) -> impl Iterator<Item = &OsStr>