pub struct FastOrdIdent(pub Ident);Expand description
Wrapper around Ident with a fast ordering function that only compares the underlying symbols. Useful when a bunch of idents need to be sorted for algorithmic reasons, but one doesn’t need the actual natural order on strings nor care about the specific order.
Tuple Fields
0: IdentTrait Implementations
Sourceimpl Clone for FastOrdIdent
impl Clone for FastOrdIdent
Sourcefn clone(&self) -> FastOrdIdent
fn clone(&self) -> FastOrdIdent
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for FastOrdIdent
impl Debug for FastOrdIdent
Sourceimpl Ord for FastOrdIdent
impl Ord for FastOrdIdent
Sourceimpl PartialEq for FastOrdIdent
impl PartialEq for FastOrdIdent
Sourceimpl PartialOrd for FastOrdIdent
impl PartialOrd for FastOrdIdent
impl Eq for FastOrdIdent
impl StructuralPartialEq for FastOrdIdent