Ident

Struct Ident 

pub struct Ident(/* private fields */);
An interned identifier.

Implementations

Source

impl Ident

pub fn new(s: impl AsRef<str>) -> Self

pub fn label(&self) -> &'static str

Return the string representation of this identifier.

pub fn into_label(self) -> String

pub fn fresh() -> Self

Create a new fresh identifier. This identifier is unique and is guaranteed not to collide with any identifier defined before.

Generated identifiers start with a special prefix that isn’t valid for Nickel identifiers. This doesn’t actually guarantee that the label of a fresh identifier will always be different from the label of a normal identifier created by Ident::new: there are ways to introduce normal identifiers that aren’t parsed as Nickel identifiers (for example, std.record.insert "%1" 42 {} causes an identifier to be created with the name “%1”).

The consequence of all this is that different Idents can have the same label. Ident::new("%1") and Ident::fresh() might both generate idents with label “%1”, but they will be different idents.

pub fn spanned(self, pos: TermPos) -> LocIdent

Attaches a position to this identifier, making it a LocIdent.

pub fn is_generated(&self) -> bool

Checks whether this identifier was generated with Ident::fresh.