pub struct LocIdent {
pub pos: TermPos,
/* private fields */
}Expand description
An identifier with a location.
The location is ignored for equality comparison and hashing; it’s mainly intended for error messages.
Fields
pos: TermPosImplementations
Sourceimpl LocIdent
impl LocIdent
pub fn new_with_pos(label: impl AsRef<str>, pos: TermPos) -> Self
pub fn new(label: impl AsRef<str>) -> Self
Sourcepub fn with_pos(self, pos: TermPos) -> LocIdent
pub fn with_pos(self, pos: TermPos) -> LocIdent
Create an identifier with the same label as this one, but a specified position.
Sourcepub fn fresh() -> Self
pub fn fresh() -> Self
Create a fresh identifier with no position. See Ident::fresh.
pub fn into_label(self) -> String
Sourcepub fn is_generated(&self) -> bool
pub fn is_generated(&self) -> bool
Checks whether this identifier was generated by Ident::fresh.
Note that this is not optimized for speed: it involves taking a lock and looking up a table.