NormalToken

Enum NormalToken 

pub enum NormalToken<'input> {
Show 167 variants Error, Identifier(&'input str), DecNumLiteral(Number), HexNumLiteral(Number), OctNumLiteral(Number), BinNumLiteral(Number), RawEnumTag(&'input str), StrEnumTagBegin, Dyn, Number, Bool, String, Array, If, Then, Else, Forall, In, Let, Rec, Match, Null, True, False, Or, As, Include, QuestionMark, Comma, Semicolon, Colon, Dollar, Equals, NotEquals, Ampersand, Dot, DoubleQuote, Plus, Minus, Times, Div, Percent, DoublePlus, DoubleEq, At, DoubleAnd, DoublePipe, Bang, Ellipsis, Fun, Import, Pipe, RightPipe, SimpleArrow, DoubleArrow, Underscore, MultiStringStart(usize), SymbolicStringStart(SymbolicStringStart<'input>), Typeof, Cast, ContractApply, ContractCheck, ContractArrayLazyApp, ContractRecordLazyApp, ContractCustom, Blame, LabelFlipPol, LabelPol, LabelGoDom, LabelGoCodom, LabelGoField, LabelGoArray, LabelGoDict, LabelInsertTypeVar, LabelLookupTypeVar, Seal, Unseal, EnumEmbed, RecordMap, RecordInsert, RecordInsertWithOpts, RecordRemove, RecordRemoveWithOpts, RecordEmptyWithTail, RecordSealTail, RecordUnsealTail, Seq, DeepSeq, OpForce, ArrayLength, RecordFields, RecordFieldsWithOpts, RecordValues, NumberArcCos, NumberArcSin, NumberArcTan, NumberArcTan2, NumberCos, NumberSin, NumberTan, NumberLog, Pow, Trace, RecordHasField, RecordHasFieldWithOpts, ArrayMap, ArrayAt, ArrayGen, OpRecForce, OpRecDefault, RecordFieldIsDefined, RecordFieldIsDefinedWithOpts, RecordSplitPair, RecordDisjointMerge, RecordMergeContract, RecordFreeze, Default, Doc, Optional, Priority, Force, NotExported, OpHash, Serialize, Deserialize, StringSplit, StringTrim, StringChars, StringUppercase, StringLowercase, StringContains, StringCompare, StringReplace, StringReplaceRegex, StringIsMatch, StringFind, StringFindAll, StringLength, StringSubstr, StringBase64Encode, StringBase64Decode, ToString, NumberFromString, EnumFromString, EnumGetArg, EnumMakeVariant, EnumIsVariant, EnumGetTag, LabelWithMessage, LabelWithNotes, LabelAppendNote, LabelPushDiag, ArraySlice, EvalNix, LBrace, RBrace, LBracket, RBracket, LParen, RParen, LAngleBracket, LessOrEq, RAngleBracket, GreaterOrEq, EnumOpen, EnumClose, LineComment,
}
The tokens in normal mode.

Variants



Error



Identifier(&'input str)



DecNumLiteral(Number)



HexNumLiteral(Number)



OctNumLiteral(Number)



BinNumLiteral(Number)



RawEnumTag(&'input str)



StrEnumTagBegin



Dyn



Number



Bool



String



Array



If



Then



Else



Forall



In



Let



Rec



Match



Null



True



False



Or

Or isn’t a reserved keyword. It is a contextual keyword (a keyword that can be used as an identifier because it’s not ambiguous) within patterns.



As

As isn’t a reserved keyword. It is a contextual keyword (a keyword that can be used as an identifier because it’s not ambiguous) within the import xxx as yyy construct.



Include

Include isn’t a reserved keyword either. It is a contextual keyword (a keyword that can be used as an identifier because it’s not ambiguous) within a record literal.



QuestionMark



Comma



Semicolon



Colon



Dollar



Equals



NotEquals



Ampersand



Dot



DoubleQuote



Plus



Minus



Times



Div



Percent



DoublePlus



DoubleEq



At



DoubleAnd



DoublePipe



Bang



Ellipsis



Fun



Import



Pipe



RightPipe



SimpleArrow



DoubleArrow



Underscore



MultiStringStart(usize)



SymbolicStringStart(SymbolicStringStart<'input>)



Typeof



Cast



ContractApply



ContractCheck



ContractArrayLazyApp



ContractRecordLazyApp



ContractCustom



Blame



LabelFlipPol



LabelPol



LabelGoDom



LabelGoCodom



LabelGoField



LabelGoArray



LabelGoDict



LabelInsertTypeVar



LabelLookupTypeVar



Seal



Unseal



EnumEmbed



RecordMap



RecordInsert



RecordInsertWithOpts



RecordRemove



RecordRemoveWithOpts



RecordEmptyWithTail



RecordSealTail



RecordUnsealTail



Seq



DeepSeq



OpForce



ArrayLength



RecordFields



RecordFieldsWithOpts



RecordValues



NumberArcCos



NumberArcSin



NumberArcTan



NumberArcTan2



NumberCos



NumberSin



NumberTan



NumberLog



Pow



Trace



RecordHasField



RecordHasFieldWithOpts



ArrayMap



ArrayAt



ArrayGen



OpRecForce



OpRecDefault



RecordFieldIsDefined



RecordFieldIsDefinedWithOpts



RecordSplitPair



RecordDisjointMerge



RecordMergeContract



RecordFreeze



Default



Doc



Optional



Priority



Force



NotExported



OpHash



Serialize



Deserialize



StringSplit



StringTrim



StringChars



StringUppercase



StringLowercase



StringContains



StringCompare



StringReplace



StringReplaceRegex



StringIsMatch



StringFind



StringFindAll



StringLength



StringSubstr



StringBase64Encode



StringBase64Decode



ToString



NumberFromString



EnumFromString



EnumGetArg



EnumMakeVariant



EnumIsVariant



EnumGetTag



LabelWithMessage



LabelWithNotes



LabelAppendNote



LabelPushDiag



ArraySlice



EvalNix



LBrace



RBrace



LBracket



RBracket



LParen



RParen



LAngleBracket



LessOrEq



RAngleBracket



GreaterOrEq



EnumOpen



EnumClose



LineComment