RawSpan

Struct RawSpan 

pub struct RawSpan {
    pub src_id: FileId,
    pub start: ByteIndex,
    pub end: ByteIndex,
}
A position span identified by a starting byte offset and an ending byte offset in a file.

end is the offset of the last character plus one.

Fields

src_id: FileIdstart: ByteIndexend: ByteIndex

Implementations

Source

impl RawSpan

pub fn fuse(self, other: RawSpan) -> Option<RawSpan>

Fuse two spans if they are from the same source file. The resulting span is the smallest span that contain both self and other.

pub fn from_codespan(src_id: FileId, span: Span) -> Self

Create a RawSpan from a span as represented by the codespan library.

pub fn from_range<T>(src_id: FileId, range: Range<T>) -> Self
where u32: TryFrom<T>,

Create a span from a numeric range. If either start or end is too large to be represented, u32::MAX is used instead.

pub fn to_range<T>(self) -> Range<T>
where T: TryFrom<u32> + Max,

Convert this span to a numeric index range. If either start or end is too large to be represented, T::MAX is used instead.

pub fn start_pos(&self) -> RawPos

Return the start of this range.

pub fn contains(&self, pos: RawPos) -> bool

Check whether this span contains a position.

pub fn contains_span(&self, other: RawSpan) -> bool

Check whether this span contains another span.