pub enum DictTypeFlavour {
Type,
Contract,
}Expand description
Flavour of a dictionary type. There are currently two way of writing a dictionary type-ish
object: as a dictionary contract {_ | T} or as a dictionary type {_ : T}. Ideally, the
former wouldn’t even be a type but mostly syntactic sugar for a builtin contract application,
or maybe a proper AST node.
However, the LSP needs to handle both dictionary types and contracts specifically in order to provide good completion. As we added dictionary contract just before 1.0 to fix a non trivial issue with respect to polymorphic contracts (GitHub issue), the solution to just tweak dictionary types to be able to hold both kinds - generating a different contract - seemed to be the simplest to preserve the user experience (LSP, handling of dictionary when reporting a contract blame, etc.).
Dictionary contracts might get a proper AST node later on.
Variants