RecordRowsF

Enum RecordRowsF 

pub enum RecordRowsF<Ty, RRows> {
    Empty,
    Extend {
        row: RecordRowF<Ty>,
        tail: RRows,
    },
    TailVar(LocIdent),
    TailDyn,
}
Generic sequence of record rows potentially with a type variable or Dyn in tail position.

As other types with the F suffix, this type is parametrized by one or more recursive unfoldings. See TypeF for more details.

Type parameters

  • Ty is the recursive unfolding of a Nickel type stored inside one row. In practice, a wrapper around an instantiation of TypeF.
  • RRows is the recursive unfolding of record rows (the tail of this row sequence). In practice, a wrapper around an instantiation of RecordRowsF.

Variants



Empty



Extend

Fields

row: RecordRowF<Ty>
tail: RRows


TailVar(LocIdent)



TailDyn

Implementations

Source

impl<Ty, RRows> RecordRowsF<Ty, RRows>

pub fn try_map_state<TyO, RRowsO, FTy, FRRows, S, E>( self, f_ty: FTy, f_rrows: FRRows, state: &mut S, ) -> Result<RecordRowsF<TyO, RRowsO>, E>
where FTy: FnMut(Ty, &mut S) -> Result<TyO, E>, FRRows: FnMut(RRows, &mut S) -> Result<RRowsO, E>,

Map functions over the children nodes of record rows, when seen as a tree. The mutable state ( S) is threaded through the calls to the mapped functions. Functions are fallible and may return an error E, which causes try_map_state to return early with the same error.

If we put aside the state and the error (see [RecordRowsF::map), this function makes RecordRowsF a functor (of arity 2). As hinted by the type signature, this function just maps on “one-level” of recursion, so to speak. Take the instantiated version RecordRows, and record rows of the form {foo : T, bar: U, baz: V}. Then, calling try_map_state(f_ty, f_rrows, state) on these rows will map f_ty onto T and f_rrows onto {bar : U, baz: V}.

Note that f_ty isn’t mapped onto U and V recursively: map isn’t a recursive operation. It’s however a building block to express recursive operations: as an example, see crate::ast::typ::RecordRows::traverse.

pub fn try_map<TyO, RRowsO, FTy, FRRows, E>( self, f_ty: FTy, f_rrows: FRRows, ) -> Result<RecordRowsF<TyO, RRowsO>, E>
where FTy: FnMut(Ty) -> Result<TyO, E>, FRRows: FnMut(RRows) -> Result<RRowsO, E>,

Variant of try_map_state without threaded state.

pub fn map_state<TyO, RRowsO, FTy, FRRows, S>( self, f_ty: FTy, f_rrows: FRRows, state: &mut S, ) -> RecordRowsF<TyO, RRowsO>
where FTy: FnMut(Ty, &mut S) -> TyO, FRRows: FnMut(RRows, &mut S) -> RRowsO,

Variant of try_map_state with infallible functions.

pub fn map<TyO, RRowsO, FTy, FRRows>( self, f_ty: FTy, f_rrows: FRRows, ) -> RecordRowsF<TyO, RRowsO>
where FTy: FnMut(Ty) -> TyO, FRRows: FnMut(RRows) -> RRowsO,

Variant of try_map_state without threaded state and with infallible functions.