pub enum VarKind {
Type,
EnumRows {
excluded: HashSet<Ident>,
},
RecordRows {
excluded: HashSet<Ident>,
},
}Expand description
The kind of a quantified type variable.
Nickel uses several forms of polymorphism. A type variable can be substituted for a type, as in
id : forall a. a -> a, for record rows as in access_foo : forall a . {foo : Number; a} -> Number}, or for enum rows. This information is implicit in the source syntax: we don’t require
users to write e.g. forall a :: Type or forall a :: Rows. But the kind of a variable is
required for the typechecker. It is thus determined during parsing and stored as VarKind where
type variables are introduced, that is, on forall quantifiers.
Variants
Type
EnumRows
excluded keeps track of which rows appear somewhere alongside the tail, and therefore
cannot appear in the tail. For instance forall r. { ; r } -> { x : Number ; r } assumes
RecordRows
Same as for Self::EnumRows.