pub struct EnumRowF<Ty> {
pub id: LocIdent,
pub typ: Option<Ty>,
}Expand description
An enum row, mapping an identifier to an optional type. If the associated type is None, this
represent a bare (unapplied) enum tag such as 'foo. If the enum is applied (a variant), the
type is store in typ. An enum type is a set of enum rows, represented as a sequence of
EnumRows, ending potentially with a type variable tail position.
Type parameters
As other types with the F suffix, this type is parametrized by one or more recursive
unfoldings (here, Ty for TypeF). See TypeF for more details.
Fields
id: LocIdenttyp: Option<Ty>Trait Implementations
Sourceimpl<Ty: CloneTo> CloneTo for EnumRowF<Ty>
impl<Ty: CloneTo> CloneTo for EnumRowF<Ty>
impl<Ty: Eq> Eq for EnumRowF<Ty>
impl<Ty> StructuralPartialEq for EnumRowF<Ty>