pub struct RecordRowF<Ty> {
pub id: LocIdent,
pub typ: Ty,
}Expand description
A record row, mapping an identifier to a type. A record type is a dictionary mapping
identifiers to Nickel type. Record types are represented as sequences of RecordRowF, ending
potentially with a type variable or Dyn in tail position.
Type parameters
As other types with the F suffix, this type is parametrized by one or more recursive
unfoldings (here, Ty for TypeF). See TypeF for more details.
Fields
id: LocIdenttyp: TyTrait Implementations
Sourceimpl<Ty: Clone> Clone for RecordRowF<Ty>
impl<Ty: Clone> Clone for RecordRowF<Ty>
Sourcefn clone(&self) -> RecordRowF<Ty>
fn clone(&self) -> RecordRowF<Ty>
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<Ty: CloneTo> CloneTo for RecordRowF<Ty>
impl<Ty: CloneTo> CloneTo for RecordRowF<Ty>
Sourceimpl<Ty: Debug> Debug for RecordRowF<Ty>
impl<Ty: Debug> Debug for RecordRowF<Ty>
Sourceimpl<Ty: PartialEq> PartialEq for RecordRowF<Ty>
impl<Ty: PartialEq> PartialEq for RecordRowF<Ty>
Sourceimpl<'a, 'ast, Ty> Pretty<'a, Allocator> for &RecordRowF<Ty>
impl<'a, 'ast, Ty> Pretty<'a, Allocator> for &RecordRowF<Ty>
impl<Ty: Eq> Eq for RecordRowF<Ty>
impl<Ty> StructuralPartialEq for RecordRowF<Ty>