pub enum ChunkLiteralPart {
Str(String),
Char(char),
}Expand description
A string chunk literal atom, being either a string or a single char.
Because of the way the lexer handles escaping and interpolation, a contiguous static string
"Some \\ \%{escaped} string" will be lexed as a sequence of such atoms.
Variants