pub enum LastPattern<P> {
Normal(P),
Ellipsis(Option<LocIdent>),
}Expand description
The last match in a data structure pattern. This can either be a normal match, or an ellipsis
which can capture the rest of the data structure. The type parameter P is the type of the
pattern of the data structure (ellipsis are supported for both array and record patterns).
Example
- In
{foo={}, bar}, the last match is an normal match. - In
{foo={}, bar, ..}, the last match is a non-capturing ellipsis. - In
{foo={}, bar, ..rest}, the last match is a capturing ellipsis.
Variants
Normal(P)
The last field is a normal match. In this case the pattern is “closed” so every record fields should be matched.
Ellipsis(Option<LocIdent>)
The pattern is “open” , ..}. Optionally you can bind a record containing the remaining
fields to an Identifier using the syntax , ..y}.