pub enum TailPattern {
Empty,
Open,
Capture(LocIdent),
}Expand description
The tail of a data structure pattern (record or array) which might capture the rest of said data structure.
Variants
Empty
The pattern is closed, i.e. it doesn’t allow more fields. For example, {foo, bar}.
Open
The pattern ends with an ellipsis, making it open. For example, {foo, bar, ..}.
Capture(LocIdent)
The pattern ends with an ellispis and a variable capturing the rest of the record. For
example, {foo, bar, ..rest}.
Implementations