pub struct Pattern<'ast> {
pub data: PatternData<'ast>,
pub alias: Option<LocIdent>,
pub pos: TermPos,
}Expand description
A generic pattern, that can appear in a match expression (not yet implemented) or in a destructuring let-binding.
Fields
data: PatternData<'ast>The content of this pattern
alias: Option<LocIdent>A potential alias for this pattern, capturing the whole matched value. In the source
language, an alias is introduced by x @ <pattern>, where x is an arbitrary identifier.
pos: TermPosThe position of the pattern in the source.
Implementations