pub struct Environment<K: Hash + Eq, V: PartialEq> { /* private fields */ }Expand description
An environment as a linked-list of hashmaps.
Each node of the linked-list corresponds to what is called “a layer”, where only the current layer can be modified, the previous ones are only accessible for lookup.
For the generic parameters, K is the type for the environment
keys, and V are their value.
The linked list is composed of the current layer and the previous layers.
The current layer is stored as an Rc<Hashmap>.
Insertions are made by “split-on-write”: if the current layer has no other references, it is mutated. If it has other references, the current layer is pushed down as the new “previous” layer, and a new layer is started.
Implementations
Sourceimpl<K: Hash + Eq, V: PartialEq> Environment<K, V>
impl<K: Hash + Eq, V: PartialEq> Environment<K, V>
Sourcepub fn iter_layers(&self) -> EnvLayerIter<'_, K, V> ⓘ
pub fn iter_layers(&self) -> EnvLayerIter<'_, K, V> ⓘ
Creates an iterator that visits all layers from the most recent one to the oldest.
The element iterator type is Rc<HashMap<K, V>>.
Sourcepub fn iter_elems(&self) -> impl Iterator<Item = (&K, &V)>
pub fn iter_elems(&self) -> impl Iterator<Item = (&K, &V)>
Creates an iterator that visits all elements from the Environment, from the oldest layer to
the most recent one. It uses this order, so calling collect on this iterator to create a
hashmap would have the same values as the Environment. The element iterator type is (&'env K, &'env V), with 'env being the lifetime of the Environment.