pub struct Ident(/* private fields */);Expand description
An interned identifier.
Implementations
Sourceimpl Ident
impl Ident
pub fn new(s: impl AsRef<str>) -> Self
pub fn into_label(self) -> String
Sourcepub fn fresh() -> Self
pub fn fresh() -> Self
Create a new fresh identifier. This identifier is unique and is guaranteed not to collide with any identifier defined before. Generated identifiers start with a special prefix that can’t be used by normal, user-defined identifiers.
FIXME: the comment above isn’t true: the identifier isn’t guaranteed to
be unique because there are ways to introduce identifiers that aren’t
parsed as Nickel identifiers. For example, std.record.insert "%1" 42 {} causes
an identifier to be created with the name “%1”.