pub enum TermPos {
Original(RawSpan),
Inherited(RawSpan),
None,
}Expand description
The position span of a term.
Variants
Original(RawSpan)
The term exactly corresponds to an original expression in the source, or is a construct introduced by program transformation that corresponds to an original span in the source.
Inherited(RawSpan)
The term is the result of the evaluation of an original expression in the source.
None
The term couldn’t be assigned a position (usually generated during execution or program transformations).
Implementations
Sourceimpl TermPos
impl TermPos
Sourcepub fn map<F: FnOnce(RawSpan) -> RawSpan>(self, f: F) -> Self
pub fn map<F: FnOnce(RawSpan) -> RawSpan>(self, f: F) -> Self
Apply a transformation to the inner position, if any.
pub fn as_opt_ref(&self) -> Option<&RawSpan>
pub fn into_opt(self) -> Option<RawSpan>
Sourcepub fn src_id(&self) -> Option<FileId>
pub fn src_id(&self) -> Option<FileId>
Returns the file id associated to this position, if the position is defined, or None
otherwise.
Sourcepub fn or(self, other: Self) -> Self
pub fn or(self, other: Self) -> Self
Return self if self not Self::None, or other otherwise.
Sourcepub fn xor(self, other: Self) -> Self
pub fn xor(self, other: Self) -> Self
Return either self or other if and only if exactly one of them is defined. If both are
None or both are defined, None is returned.
Sourcepub fn is_def(&self) -> bool
pub fn is_def(&self) -> bool
Determine is the position is defined. Return false if it is None, and true otherwise.
Sourcepub fn into_inherited(self) -> Self
pub fn into_inherited(self) -> Self
Try to set the position to inherited, if it wasn’t already. If self was None, None is
returned.
Sourcepub fn fuse(self, other: Self) -> Self
pub fn fuse(self, other: Self) -> Self
Fuse two positions if they are from the same source file.
- If both positions are defined and from the same file, the resulting position is the smallest span that contain both.
- If both positions are defined but aren’t from the same file, this returns
TermPos::None - If at most one position is defined, the other is returned (whether defined or not).