pub struct RawSpan {
pub src_id: FileId,
pub start: ByteIndex,
pub end: ByteIndex,
}Expand description
A position span identified by a starting byte offset and an ending byte offset in a file.
end is the offset of the last character plus one.
Fields
src_id: FileIdstart: ByteIndexend: ByteIndexImplementations
Sourceimpl RawSpan
impl RawSpan
Sourcepub fn fuse(self, other: RawSpan) -> Option<RawSpan>
pub fn fuse(self, other: RawSpan) -> Option<RawSpan>
Fuse two spans if they are from the same source file. The resulting span is the smallest
span that contain both self and other.
Sourcepub fn from_codespan(src_id: FileId, span: Span) -> Self
pub fn from_codespan(src_id: FileId, span: Span) -> Self
Create a RawSpan from a span as represented by the codespan library.
Sourcepub fn from_range<T>(src_id: FileId, range: Range<T>) -> Self
pub fn from_range<T>(src_id: FileId, range: Range<T>) -> Self
Create a span from a numeric range. If either start or end is too large to be represented,
u32::MAX is used instead.
Sourcepub fn to_range<T>(self) -> Range<T>
pub fn to_range<T>(self) -> Range<T>
Convert this span to a numeric index range. If either start or end is too large to be
represented, T::MAX is used instead.
Sourcepub fn contains_span(&self, other: RawSpan) -> bool
pub fn contains_span(&self, other: RawSpan) -> bool
Check whether this span contains another span.