pub trait AttachToAst<'ast, T> {
// Required method
fn attach_to_ast(self, alloc: &'ast AstAlloc, ast: Ast<'ast>) -> T;
}Expand description
Trait for structures representing annotations which can be combined with a term to build
another term, or another structure holding a term, such as a field. T is the said target
structure.